import { Http,Util,Errorlog } from '@/utils';
import ControlService from '@/widgets/control-service';
import EMITEMService from '@/service/emitem/emitem-service';
import Main3Model from './main3-form-model';
import EMITEMTYPEService from '@/service/emitemtype/emitemtype-service';
import EMACCLASSService from '@/service/emacclass/emacclass-service';
import EMSTOREService from '@/service/emstore/emstore-service';
import EMSTOREPARTService from '@/service/emstorepart/emstorepart-service';
import PFUNITService from '@/service/pfunit/pfunit-service';
import PFEMPService from '@/service/pfemp/pfemp-service';
import EMSERVICEService from '@/service/emservice/emservice-service';


/**
 * Main3 部件服务对象
 *
 * @export
 * @class Main3Service
 */
export default class Main3Service extends ControlService {

    /**
     * 物品服务对象
     *
     * @type {EMITEMService}
     * @memberof Main3Service
     */
    public appEntityService: EMITEMService = new EMITEMService({ $store: this.getStore() });

    /**
     * 设置从数据模式
     *
     * @type {boolean}
     * @memberof Main3Service
     */
    public setTempMode(){
        this.isTempMode = false;
    }

    /**
     * Creates an instance of Main3Service.
     * 
     * @param {*} [opts={}]
     * @memberof Main3Service
     */
    constructor(opts: any = {}) {
        super(opts);
        this.model = new Main3Model();
    }

    /**
     * 物品类型服务对象
     *
     * @type {EMITEMTYPEService}
     * @memberof Main3Service
     */
    public emitemtypeService: EMITEMTYPEService = new EMITEMTYPEService();

    /**
     * 总帐科目服务对象
     *
     * @type {EMACCLASSService}
     * @memberof Main3Service
     */
    public emacclassService: EMACCLASSService = new EMACCLASSService();

    /**
     * 仓库服务对象
     *
     * @type {EMSTOREService}
     * @memberof Main3Service
     */
    public emstoreService: EMSTOREService = new EMSTOREService();

    /**
     * 仓库库位服务对象
     *
     * @type {EMSTOREPARTService}
     * @memberof Main3Service
     */
    public emstorepartService: EMSTOREPARTService = new EMSTOREPARTService();

    /**
     * 计量单位服务对象
     *
     * @type {PFUNITService}
     * @memberof Main3Service
     */
    public pfunitService: PFUNITService = new PFUNITService();

    /**
     * 职员服务对象
     *
     * @type {PFEMPService}
     * @memberof Main3Service
     */
    public pfempService: PFEMPService = new PFEMPService();

    /**
     * 服务商服务对象
     *
     * @type {EMSERVICEService}
     * @memberof Main3Service
     */
    public emserviceService: EMSERVICEService = new EMSERVICEService();

    /**
     * 处理数据
     *
     * @private
     * @param {Promise<any>} promise
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    private doItems(promise: Promise<any>, deKeyField: string, deName: string): Promise<any> {
        return new Promise((resolve, reject) => {
            promise.then((response: any) => {
                if (response && response.status === 200) {
                    const data = response.data;
                    data.forEach((item:any,index:number) =>{
                        item[deName] = item[deKeyField];
                        data[index] = item;
                    });
                    resolve(data);
                } else {
                    reject([])
                }
            }).catch((response: any) => {
                reject([])
            });
        });
    }

    /**
     * 获取跨实体数据集合
     *
     * @param {string} serviceName 服务名称
     * @param {string} interfaceName 接口名称
     * @param {*} data
     * @param {boolean} [isloading]
     * @returns {Promise<any[]>}
     * @memberof  Main3Service
     */
    @Errorlog
    public getItems(serviceName: string, interfaceName: string, context: any = {}, data: any, isloading?: boolean): Promise<any[]> {
        if (Object.is(serviceName, 'EMITEMTYPEService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.emitemtypeService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'emitemtypeid', 'emitemtype');
        }
        if (Object.is(serviceName, 'EMACCLASSService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.emacclassService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'emacclassid', 'emacclass');
        }
        if (Object.is(serviceName, 'EMSTOREService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.emstoreService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'emstoreid', 'emstore');
        }
        if (Object.is(serviceName, 'EMSTOREPARTService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.emstorepartService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'emstorepartid', 'emstorepart');
        }
        if (Object.is(serviceName, 'PFUNITService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.pfunitService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'pfunitid', 'pfunit');
        }
        if (Object.is(serviceName, 'PFEMPService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.pfempService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'pfempid', 'pfemp');
        }
        if (Object.is(serviceName, 'EMSERVICEService') && Object.is(interfaceName, 'FetchDefault')) {
            return this.doItems(this.emserviceService.FetchDefault(JSON.parse(JSON.stringify(context)),data, isloading), 'emserviceid', 'emservice');
        }

        return Promise.reject([])
    }

    /**
     * 启动工作流
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public wfstart(action: string,context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        data = this.handleWFData(data);
        context = this.handleRequestData(action,context,data).context;
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](context,data, isloading);
            } else {
                result = this.appEntityService.Create(context,data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

    /**
     * 提交工作流
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public wfsubmit(action: string,context: any = {}, data: any = {}, isloading?: boolean): Promise<any> {
        data = this.handleWFData(data,true);
        context = this.handleRequestData(action,context,data).context;
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](context,data, isloading);
            } else {
                result = this.appEntityService.Create(context,data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }


    /**
     * 添加数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public add(action: string, context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                result = this.appEntityService.Create(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

    /**
     * 删除数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public delete(action: string, context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                result = this.appEntityService.Remove(Context,Data, isloading);
            }
            result.then((response) => {
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

    /**
     * 修改数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public update(action: string, context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                result = this.appEntityService.Update(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

    /**
     * 查询数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public get(action: string,context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                result = this.appEntityService.Get(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

    /**
     * 加载草稿
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public loadDraft(action: string,context: any = {}, data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        //仿真主键数据
        Data.emitemid = Util.createUUID();
        Data.emitem = Data.emitemid;
        return new Promise((resolve: any, reject: any) => {
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                result = this.appEntityService.GetDraft(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response, true);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        });
    }

     /**
     * 前台逻辑
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof Main3Service
     */
    @Errorlog
    public frontLogic(action:string,context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data);
        return new Promise((resolve: any, reject: any)=>{
            let result: Promise<any>;
            const _appEntityService: any = this.appEntityService;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            } else {
                return Promise.reject({ status: 500, data: { title: '失败', message: '系统异常' } });
            }
            result.then((response) => {
                this.handleResponse(action, response,true);
                resolve(response);
            }).catch(response => {
                reject(response);
            });
        })
    }

    /**
     * 处理请求数据
     * 
     * @param action 行为 
     * @param data 数据
     * @memberof Main3Service
     */
    public handleRequestData(action: string,context:any, data: any = {}){
        let mode: any = this.getMode();
        if (!mode && mode.getDataItems instanceof Function) {
            return data;
        }
        let formItemItems: any[] = mode.getDataItems();
        let requestData:any = {};
        formItemItems.forEach((item:any) =>{
            if(item && item.dataType && Object.is(item.dataType,'FONTKEY')){
                if(item && item.prop){
                    requestData[item.prop] = context[item.name];
                }
            }else{
                if(item && item.prop){
                    requestData[item.prop] = data[item.name];
                }
            }
        });
        if(data && data.viewparams){
            Object.assign(requestData,data.viewparams);
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        if(tempContext && tempContext.srfsessionid){
            tempContext.srfsessionkey = tempContext.srfsessionid;
            delete tempContext.srfsessionid;
        }
        return {context:tempContext,data:requestData};
    }

}